@@ -1,6 +1,6 @@
 from django.contrib.postgres.fields import ArrayField as DjangoArrayField
 
-from django_search_arrayfield.forms.fields import DynamicArrayField
+from ..forms.fields import DynamicArrayField
 
 
 class ArrayField(DjangoArrayField):
